summaryrefslogtreecommitdiffhomepage
path: root/template/code.qtpl.go
diff options
context:
space:
mode:
authorChloe Kudryavtsev <toast@toast.cafe>2019-12-19 13:51:16 -0500
committerChloe Kudryavtsev <toast@toast.cafe>2019-12-19 13:51:16 -0500
commit03a8a17e57a5dff33e2060625e5e8a48b777a430 (patch)
tree0ca1b13b476671e88e1f48694d82fd537c308847 /template/code.qtpl.go
parentfeat: add redis storage tests (diff)
v2.1.0 - RELEASE!v2.1.0
Diffstat (limited to 'template/code.qtpl.go')
-rw-r--r--template/code.qtpl.go81
1 files changed, 61 insertions, 20 deletions
diff --git a/template/code.qtpl.go b/template/code.qtpl.go
index 2fa1401..3f4e19b 100644
--- a/template/code.qtpl.go
+++ b/template/code.qtpl.go
@@ -25,7 +25,7 @@ func StreamCode(qw422016 *qt422016.Writer, lang, data string) {
qw422016.N().S(`
`)
//line template/code.qtpl:3
- streamlayout(qw422016, " ", code_scripts(lang), "", code_contents(lang, data), code_bodyscripts(lang))
+ streamlayout(qw422016, code_css(), code_scripts(lang), "", code_contents(lang, data), code_bodyscripts(lang))
//line template/code.qtpl:3
qw422016.N().S(`
`)
@@ -161,47 +161,88 @@ func code_bodyscripts(lang string) string {
//line template/code.qtpl:23
}
// The code contents.
//line template/code.qtpl:26
-func streamcode_contents(qw422016 *qt422016.Writer, lang, data string) {
+func streamcode_css(qw422016 *qt422016.Writer) {
//line template/code.qtpl:26
qw422016.N().S(`
+ <style>
+ pre[class*="language-"] code[class*="language-"] {
+ white-space: pre-wrap;
+ }
+ </style>
+`)
+//line template/code.qtpl:32
+}
+
+//line template/code.qtpl:32
+func writecode_css(qq422016 qtio422016.Writer) {
+//line template/code.qtpl:32
+ qw422016 := qt422016.AcquireWriter(qq422016)
+//line template/code.qtpl:32
+ streamcode_css(qw422016)
+//line template/code.qtpl:32
+ qt422016.ReleaseWriter(qw422016)
+//line template/code.qtpl:32
+}
+
+//line template/code.qtpl:32
+func code_css() string {
+//line template/code.qtpl:32
+ qb422016 := qt422016.AcquireByteBuffer()
+//line template/code.qtpl:32
+ writecode_css(qb422016)
+//line template/code.qtpl:32
+ qs422016 := string(qb422016.B)
+//line template/code.qtpl:32
+ qt422016.ReleaseByteBuffer(qb422016)
+//line template/code.qtpl:32
+ return qs422016
+//line template/code.qtpl:32
+}
+
+// The code contents.
+
+//line template/code.qtpl:35
+func streamcode_contents(qw422016 *qt422016.Writer, lang, data string) {
+//line template/code.qtpl:35
+ qw422016.N().S(`
<pre><code class='language-`)
-//line template/code.qtpl:27
+//line template/code.qtpl:36
qw422016.E().S(lang)
-//line template/code.qtpl:27
+//line template/code.qtpl:36
qw422016.N().S(`'>`)
-//line template/code.qtpl:27
+//line template/code.qtpl:36
qw422016.E().S(data)
-//line template/code.qtpl:27
+//line template/code.qtpl:36
qw422016.N().S(`</code></pre>
`)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
}
-//line template/code.qtpl:28
+//line template/code.qtpl:37
func writecode_contents(qq422016 qtio422016.Writer, lang, data string) {
-//line template/code.qtpl:28
+//line template/code.qtpl:37
qw422016 := qt422016.AcquireWriter(qq422016)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
streamcode_contents(qw422016, lang, data)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
qt422016.ReleaseWriter(qw422016)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
}
-//line template/code.qtpl:28
+//line template/code.qtpl:37
func code_contents(lang, data string) string {
-//line template/code.qtpl:28
+//line template/code.qtpl:37
qb422016 := qt422016.AcquireByteBuffer()
-//line template/code.qtpl:28
+//line template/code.qtpl:37
writecode_contents(qb422016, lang, data)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
qs422016 := string(qb422016.B)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
qt422016.ReleaseByteBuffer(qb422016)
-//line template/code.qtpl:28
+//line template/code.qtpl:37
return qs422016
-//line template/code.qtpl:28
+//line template/code.qtpl:37
}
@@ -161,47 +161,88 @@ func code_bodyscripts(lang string) string {
//line template/code.qtpl:23
}
-// The code contents.
+// The code css.
//line template/code.qtpl:26